import React from "react";
import { Button } from "@orbit-ui/react-button";
import { PureComponent, createRef } from "react";
import { SIZES } from "./sizes";
import { func, oneOf, string } from "prop-types";
import { withHandlerProxy } from "@orbit-ui/react-components-shared";
export class MultiSelectClearButton extends PureComponent {
  constructor(...args) {
    super(...args);
    this._buttonRef = createRef();
    this.handleClick = withHandlerProxy(this, "onClick", false);
  }

  render() {
    const {
      text,
      className,
      size
    } = this.props;
    return React.createElement(Button, {
      onClick: this.handleClick,
      ghost: true,
      compact: true,
      size: size,
      className: className,
      type: "button",
      ref: this._buttonRef
    }, text);
  }

}
MultiSelectClearButton.displayName = "MultiSelectClearButton";
MultiSelectClearButton.propTypes = {
  /**
   * The button text.
   */
  text: string,

  /**
   * Called on click.
   * @param {SyntheticEvent} event - React's original SyntheticEvent.
   * @param {Object} props - All the props.
   * @returns {void}
   */
  // eslint-disable-next-line react/no-unused-prop-types
  onClick: func,

  /**
   * A clear button can have different sizes.
   */
  size: oneOf(SIZES),

  /**
   * Additional classes.
   */
  className: string
};
MultiSelectClearButton.defaultProps = {
  text: "Clear all"
};